\name{nLogLik.trecase.A}
\alias{nLogLik.trecase.A}
\title{Negative log likelihood of an autosomal joint TReC and ASE counts model.}
\description{
  Calculates negative log(likelihood) of an autosomal joint TReC and ASE counts model at a given set of parameters
}
\usage{
nLogLik.trecase.A(coef, phi, theta, index, y, n, n0B, kappas, hessian=FALSE)}
\arguments{
  \item{coef}{parameters}
  \item{phi}{total read counts overdispersion}
  \item{theta}{allele specific counts overdispersion}
  \item{index}{vector defining the cross of the mouse, female - AB=1, BA=2, AA=3, BB=4, and male - AB=5, BA=6, AA=7, BB=8.
  If mice are of only one sex, AB=1, BA=2, AA=3, BB=4.}
  \item{y}{vector of total read counts}
  \item{n}{vector of allele specific counts for each mouse}  
  \item{n0B}{vector of allele specific counts for allele B}
  \item{kappas}{Offset parameter, given as overall TReC for the mouse.}
  \item{hessian}{a logical option whether to calculate a Hessian matrix, the default values is set to FALSE.}
}

\value{
  output - list(nll=-log.likelihood,hessian=hessian matrix)
}
\author{ Vasyl Zhabotynsky vasyl@unc.edu }
\keyword{ utilities }

\examples{
# get negative-log likelihood at the given point:
nLogLik.trecase.A(coef=rep(1,11), phi=1, theta=1, index=data.A$index, y=data.A$y[1,], 
          n=data.A$n[1,], n0B=data.A$n0B[1,], kappas=data.A$kappas)
}
