\name{nLogLik.trecase.X}
\alias{nLogLik.trecase.X}
\title{Negative log likelihood of an X chromosome joint TReC and ASE counts model.}
\description{
  Calculates negative log(likelihood) of an X chromosome joint TReC and ASE counts model at a given set of parameters
}
\usage{
nLogLik.trecase.X(coef, phi, theta, index, y, n, n0B, kappas, tausB, gene.switch=FALSE, hessian=FALSE)}
\arguments{
  \item{coef}{parameters}
  \item{phi}{total read counts overdispersion}
  \item{theta}{allele specific counts overdispersion}
  \item{index}{vector defining the cross of the mouse, female - AB=1, BA=2, AA=3, BB=4, and male - AB=5, BA=6, AA=7, BB=8.
  If mice are of only one sex, AB=1, BA=2, AA=3, BB=4.}
  \item{y}{vector of total read counts}
  \item{n}{vector of allele specific counts for each mouse}  
  \item{n0B}{vector of allele specific counts for allele B}
  \item{kappas}{Offset parameter, given as overall TReC for the mouse.}
  \item{tausB}{\emph{Xce} effect: expression of allele B relative to the overall allele specific count for each mouse.}
  \item{gene.switch}{TRUE/FALSE to switch tausB to 1-tausB (for example, for \emph{Xist})}
  \item{hessian}{a logical option whether to calculate a Hessian matrix, the default values is set to FALSE.}
}

\value{
  output - list(nll=-log.likelihood,hessian=hessian matrix)
}
\author{ Vasyl Zhabotynsky vasyl@unc.edu }
\keyword{ utilities }

\examples{
# get negative-log likelihood at the given point:
nLogLik.trecase.X(coef=rep(1,9), phi=1, theta=1, index=data.X$index, y=data.X$y[1,], 
          n=data.X$n[1,], n0B=data.X$n0B[1,], kappas=data.X$kappas, tausB=data.X$tausB, gene.switch=TRUE)
}
