\name{proc.trec.A}
\alias{proc.trec.A}
\title{Optimization wrapper for autosomes, total read counts (TReC) only}
\description{
  Performs optimization of the likelihood for TReC only model and tests with lrt test several hypotheses:
  additive, parent of origin, dominance, sex, sex specific additive, sex specific parent of origin, sex specific dominance effects.
}
\usage{
proc.trec.A(index, y, kappas=NULL, geneids=rownames(y), hessian=FALSE)}
\arguments{
  \item{index}{vector defining the cross of the mouse, female - AB=1, BA=2, AA=3, BB=4, and male - AB=5, BA=6, AA=7, BB=8.
  If mice are of only one sex, AB=1, BA=2, AA=3, BB=4.}
  \item{y}{matrix of TReC counts.}
  \item{kappas}{A parameter, specifying as overall TReC for the mouse, on log scale.
  Since it may be better to calculate these values even using genes one decides not to estimate: low counts genes, pseudogenes, one may provide them as a paramter.
  If the value is not provided, kappas will be calculated based on a \bold{y} matrix provided}
  \item{geneids}{ids of genes, if not provided, rownames of the matrix \bold{y} will be used}
  \item{hessian}{a flag whether Hessian matrix for these genes should be calculated, by default set to FALSE}
}
\value{
  a list of following matrices (if there is only one sex, only the relevant tests and matrices are outputed) :
  \item{pvals}{matrix of p-values from description for each gene corresponding row}
  \item{coef.full}{matrix of full model fit coefficients, -log(likelihood at these coefficients),phi (1 overdispersion parameter used)}  
  \item{coef.add}{matrix of additive restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.poo}{matrix of parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.dom}{matrix of dominance restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.sex}{matrix of sex restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.add}{matrix of sex specific additive restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.poo}{matrix of sex specific parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.dom}{matrix of sex specific dominance restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{errorlist}{a list of errors}
  \item{hess.lst}{a list of heassian matrices, if parameter \bold{hessian} is set to TRUE}  
}
\author{ Vasyl Zhabotynsky vasyl@unc.edu }
\seealso{\code{\link{nLogLik.trec.A}}, \code{\link{data.A}}, \code{\link{proc.trecase.A}}.}
\keyword{ methods }

\examples{
# fitting X chromosome data example, for a short model, i.e. assuming there is no allele specific reads:
trec.A.out <- proc.trec.A(index=data.A$index, y=data.A$y[1:2,], 
           kappas=data.A$kappas, geneids=data.A$geneids[1:2])
names(trec.A.out)
trec.A.out$pval

#alternatively simulated data and fit it:
dat.A <- simRX(b0f=.5, b0m=.6, b1f=.3, b1m=.4, beta_sex=.1, beta_dom=.1, n.simu=2)
trec.A.sim.out <- proc.trec.A(index=dat.A$index, y=dat.A$y,
            kappas=dat.A$kappas, geneids=dat.A$geneids)
trec.A.sim.out$pval
}
