\name{proc.trec.X}
\alias{proc.trec.X}
\title{Optimization wrapper for X chromosome, total read counts (TReC) only}
\description{
  Performs optimization of the likelihood for TReC only model and tests with lrt test several hypotheses:
  additive, parent of origin, dominance, sex, sex specific additive, male dominance deviation effects.
}
\usage{
proc.trec.X(index, y, kappas=NULL, tausB=NULL, genes.switch="ENSMUSG00000086503", geneids=rownames(y), hessian=FALSE)}
\arguments{
  \item{index}{vector defining the cross of the mouse, female - AB=1, BA=2, AA=3, BB=4, and male - AB=5, BA=6, AA=7, BB=8.
  If mice are of only one sex, AB=1, BA=2, AA=3, BB=4.}
  \item{y}{matrix of TReC counts.}
  \item{kappas}{A parameter, specifying as overall TReC for the mouse, on log scale.
  Since it may be better to calculate these values even using genes one decides not to estimate: low counts genes, pseudogenes, one may provide them as a paramter.
  If the value is not provided, kappas will be calculated based on a \bold{y} matrix provided}
  \item{tausB}{\emph{Xce} effect: expression of allele B relative to the overall allele specific count for each mouse. Use some allele specific counts to estimate the effect.
  If no values submitted, the \emph{Xce} effect of 50\% will be used. It is not recommended, since it would not estimate additive effect right, if no allele specific counts are available, try to use literature estimates.}
  \item{genes.switch}{vector of geneids you want to have \emph{Xce} effect to be switched to 1-tausB, for example, it has to be done for \emph{Xist}, by default ensembl gene id for this gene is provided}
  \item{geneids}{ids of genes, if not provided, rownames of the matrix \bold{y} will be used}
  \item{hessian}{a flag whether Hessian matrix for these genes should be calculated, by default set to FALSE}
}
\value{
  a list of following matrices (if there is only one sex, only the relevant tests and matrices are outputed) :
  \item{pvals}{matrix of p-values from description for each gene corresponding row}
  \item{coef.full}{matrix of full model fit coefficients, -log(likelihood at these coefficients),phi (1 overdispersion parameter used)}  
  \item{coef.add}{matrix of additive restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.poo}{matrix of parent of origin restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.dom}{matrix of dominance restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.sex}{matrix of sex restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.sex.add}{matrix of sex specific additive restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{coef.dev.dom}{matrix of dominance deviation for male restricted fit coefficients, -log(likelihood at these coefficients),phi}
  \item{errorlist}{a list of errors}
  \item{hess.lst}{a list of heassian matrices, if parameter \bold{hessian} is set to TRUE}  
}
\author{ Vasyl Zhabotynsky vasyl@unc.edu }
\seealso{\code{\link{nLogLik.trec.X}}, \code{\link{data.X}}, \code{\link{proc.trecase.X}}, \code{\link{get.tausB}}, \code{\link{simRX}}.}
\keyword{ methods }

\examples{
# fitting X chromosome data example, for a short model, i.e. assuming there is no allele specific reads:
trec.X.out <- proc.trec.X(index=data.X$index, y=data.X$y[1:2,], 
           kappas=data.X$kappas, tausB=data.X$tausB, geneids=data.X$geneids[1:2])
names(trec.X.out)
trec.X.out$pval

#alternatively simulated data and fit it:
dat.X <- simRX(b0f=.5, b0m=.6, b1f=.3, b1m=.4, beta_sex=.1, beta_dom=.1, n.simu=2, is.X=TRUE, tauB=.3)
trec.X.sim.out <- proc.trec.X(index=dat.X$index, y=dat.X$y,
            kappas=dat.X$kappas, tausB=dat.X$tausB, geneids=dat.X$geneids)
trec.X.sim.out$pval
}
